package com.ztmap.project.zhny.netgfswl.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ztmap.project.zhny.netgfswl.mapper.TNetGfswlMapper;
import com.ztmap.project.zhny.netgfswl.domain.TNetGfswl;
import com.ztmap.project.zhny.netgfswl.service.ITNetGfswlService;
import com.ztmap.common.utils.text.Convert;

/**
 * 光伏上网量Service业务层处理
 * 
 * @author ztmap
 * @date 2023-11-16
 */
@Service
public class TNetGfswlServiceImpl implements ITNetGfswlService 
{
    @Autowired
    private TNetGfswlMapper tNetGfswlMapper;

    /**
     * 查询光伏上网量
     * 
     * @param id 光伏上网量ID
     * @return 光伏上网量
     */
    @Override
    public TNetGfswl selectTNetGfswlById(Long id)
    {
        return tNetGfswlMapper.selectTNetGfswlById(id);
    }

    /**
     * 查询光伏上网量列表
     * 
     * @param tNetGfswl 光伏上网量
     * @return 光伏上网量
     */
    @Override
    public List<TNetGfswl> selectTNetGfswlList(TNetGfswl tNetGfswl)
    {
        return tNetGfswlMapper.selectTNetGfswlList(tNetGfswl);
    }

    /**
     * 新增光伏上网量
     * 
     * @param tNetGfswl 光伏上网量
     * @return 结果
     */
    @Override
    public int insertTNetGfswl(TNetGfswl tNetGfswl)
    {
        return tNetGfswlMapper.insertTNetGfswl(tNetGfswl);
    }

    /**
     * 修改光伏上网量
     * 
     * @param tNetGfswl 光伏上网量
     * @return 结果
     */
    @Override
    public int updateTNetGfswl(TNetGfswl tNetGfswl)
    {
        return tNetGfswlMapper.updateTNetGfswl(tNetGfswl);
    }

    /**
     * 删除光伏上网量对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTNetGfswlByIds(String ids)
    {
        return tNetGfswlMapper.deleteTNetGfswlByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除光伏上网量信息
     * 
     * @param id 光伏上网量ID
     * @return 结果
     */
    @Override
    public int deleteTNetGfswlById(Long id)
    {
        return tNetGfswlMapper.deleteTNetGfswlById(id);
    }
}
